emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] trunk r114886: Support newer versions of libjpeg on MS-Win


From: Eli Zaretskii
Subject: [Emacs-diffs] trunk r114886: Support newer versions of libjpeg on MS-Windows.
Date: Fri, 01 Nov 2013 08:53:53 +0000
User-agent: Bazaar (2.6b2)

------------------------------------------------------------
revno: 114886
revision-id: address@hidden
parent: address@hidden
author: Claudio Bley <address@hidden>
committer: Eli Zaretskii <address@hidden>
branch nick: trunk
timestamp: Fri 2013-11-01 10:52:22 +0200
message:
  Support newer versions of libjpeg on MS-Windows.
  
   src/image.c (Qlibjpeg_version): New variable.
   (syms_of_image): DEFSYM and initialize it.
  
   lisp/term/w32-win.el (dynamic-library-alist): Support newer versions
   of libjpeg starting with v7: look only for the DLL from the
   version against which Emacs was built.
modified:
  lisp/ChangeLog                 changelog-20091113204419-o5vbwnq5f7feedwu-1432
  lisp/term/w32-win.el           w32win.el-20091113204419-o5vbwnq5f7feedwu-943
  src/ChangeLog                  changelog-20091113204419-o5vbwnq5f7feedwu-1438
  src/image.c                    image.c-20091113204419-o5vbwnq5f7feedwu-2969
=== modified file 'lisp/ChangeLog'
--- a/lisp/ChangeLog    2013-11-01 03:35:35 +0000
+++ b/lisp/ChangeLog    2013-11-01 08:52:22 +0000
@@ -1,3 +1,9 @@
+2013-11-01  Claudio Bley  <address@hidden>
+
+       * term/w32-win.el (dynamic-library-alist): Support newer versions
+       of libjpeg starting with v7: look only for the DLL from the
+       version against which Emacs was built.
+
 2013-11-01  Bozhidar Batsov  <address@hidden>
 
        * progmodes/ruby-mode.el (ruby-indent-tabs-mode)

=== modified file 'lisp/term/w32-win.el'
--- a/lisp/term/w32-win.el      2013-10-10 15:30:21 +0000
+++ b/lisp/term/w32-win.el      2013-11-01 08:52:22 +0000
@@ -221,8 +221,17 @@
         '(png "libpng12d.dll" "libpng12.dll" "libpng3.dll" "libpng.dll"
               ;; these are libpng 1.2.8 from GTK+
               "libpng13d.dll" "libpng13.dll"))
-       '(jpeg "jpeg62.dll" "libjpeg.dll" "jpeg-62.dll" "jpeg.dll")
        '(tiff "libtiff3.dll" "libtiff.dll")
+       (if (> libjpeg-version 62)
+          ;; Versions of libjpeg after 6b are incompatible with
+          ;; earlier versions, and each of versions 7, 8, and 9 is
+          ;; also incompatible with the preceding ones (the core data
+          ;; structures used for communications with the library
+          ;; gained additional members with each new version).  So we
+          ;; must use only the version of the library which Emacs was
+          ;; compiled against.
+          (list 'jpeg (format "libjpeg-%d.dll" (/ libjpeg-version 10)))
+        '(jpeg "jpeg62.dll" "libjpeg.dll" "jpeg-62.dll" "jpeg.dll"))
        ;; Versions of giflib 5.0.0 and later changed signatures of
        ;; several functions used by Emacs, which makes those versions
        ;; incompatible with previous ones.  We select the correct

=== modified file 'src/ChangeLog'
--- a/src/ChangeLog     2013-10-31 08:32:42 +0000
+++ b/src/ChangeLog     2013-11-01 08:52:22 +0000
@@ -1,3 +1,8 @@
+2013-11-01  Claudio Bley  <address@hidden>
+
+       * image.c (Qlibjpeg_version): New variable.
+       (syms_of_image): DEFSYM and initialize it.
+
 2013-10-31  Jan Djärv  <address@hidden>
 
        * emacs.c (main): Skip -psn args on OSX even if ! isatty (0).

=== modified file 'src/image.c'
--- a/src/image.c       2013-10-28 21:19:38 +0000
+++ b/src/image.c       2013-11-01 08:52:22 +0000
@@ -87,11 +87,12 @@
 #define x_defined_color w32_defined_color
 #define DefaultDepthOfScreen(screen) (one_w32_display_info.n_cbits)
 
-/* Versions of libpng and libgif that we were compiled with, or -1 if
-   no PNG/GIF support was compiled in.  This is tested by w32-win.el
-   to correctly set up the alist used to search for the respective
-   image libraries.  */
-Lisp_Object Qlibpng_version, Qlibgif_version;
+/* Versions of libpng, libgif, and libjpeg that we were compiled with,
+   or -1 if no PNG/GIF support was compiled in.  This is tested by
+   w32-win.el to correctly set up the alist used to search for the
+   respective image libraries.  */
+Lisp_Object Qlibpng_version, Qlibgif_version, Qlibjpeg_version;
+
 #endif /* HAVE_NTGUI */
 
 #ifdef HAVE_NS
@@ -9411,6 +9412,14 @@
 #else
        make_number (-1)
 #endif
+        );
+  DEFSYM (Qlibjpeg_version, "libjpeg-version");
+  Fset (Qlibjpeg_version,
+#if HAVE_JPEG
+       make_number (JPEG_LIB_VERSION)
+#else
+       make_number (-1)
+#endif
        );
 #endif
 


reply via email to

[Prev in Thread] Current Thread [Next in Thread]